@@ -24,6 +24,5 @@ class DisplayMessage(StrEnum):
 
 
 class SKU:
-    LIST_AVAILABLE_ACCOUNTS = 'list_external_accounts'
-    UPDATE_LINK = 'update_link'
-    CREATE_LINK = 'create_link'
+    SYNCED_VACANCY = 'synced_vacancy'
+
