@@ -3,7 +3,7 @@ import uuid
 from datetime import datetime, timezone
 from typing import Optional, List
 
-from sqlalchemy import Column, JSON
+from sqlalchemy import Column, JSON, UniqueConstraint
 from sqlmodel import Field
 
 from ..general.models import VacanciesOrganizationModel
@@ -55,6 +55,10 @@ class Vacancy(VacanciesOrganizationModel, table=True):
     recruiter_email: Optional[str] = Field()
     recruiter_role: Optional[str] = Field()
 
+    __table_args__ = (
+        UniqueConstraint("feed_id", "reference_number", name="uq_feed_reference"),
+    )
+
 
 class Modification(VacanciesOrganizationModel, table=True):
     name: str = Field(index=True)
